@@ -2,10 +2,11 @@
 
 module Emails
   class BaseService
-    attr_reader :current_user
+    attr_reader :current_user, :params, :user
 
     def initialize(current_user, params = {})
-      @current_user, @params = current_user, params.dup
+      @current_user = current_user
+      @params = params.dup
       @user = params.delete(:user)
     end
   end
